@@ -18,6 +18,8 @@ from dhlab.text.conc_coll import Collocations, Concordance, Counts
 from dhlab.text.geo_data import GeoData, GeoNames
 from dhlab.text.parse import NER, POS, Models
 from dhlab.text.wildcard import WildcardWordSearch
+from dhlab.utils.display import css
+from dhlab.utils.files import download_from_github,get_file_from_github
 
 # ngram 
 from dhlab.ngram.ngram import Ngram, NgramBook, NgramNews
@@ -26,4 +28,7 @@ from dhlab.ngram.ngram import Ngram, NgramBook, NgramNews
 from dhlab.wordbank.wordbank import WordParadigm, WordLemma, WordForm
 
 # api
-from dhlab.api.dhlab_api import totals
\ No newline at end of file
+from dhlab.api.dhlab_api import totals
+
+# metadata
+from dhlab.metadata.natbib import metadata_query, metadata_from_urn
