@@ -166,6 +166,10 @@ def get_metadata(urns: List[str] = None) -> DataFrame:
     r = requests.post(f"{BASE_URL}/get_metadata", json=params)
     return DataFrame(r.json())
 
+def get_identifiers(identifiers: list = None) -> list:
+    """Convert a list of identifiers, oaiid, sesamid, urns or isbn10 to dhlabids"""
+    res = requests.post(f"{BASE_URL}/identifiers", json={'identifiers':[i for i in identifiers if i != '']})
+    return res.json()
 
 def get_chunks(urn: str = None, chunk_size: int = 300) -> Union[Dict, List]:
     """Get the text in the document ``urn`` as frequencies of chunks
@@ -552,9 +556,7 @@ def ngram_news(
     return df
 
 
-def get_document_frequencies(
-        urns: List[str] = None, cutoff: int = 0, words: List[str] = None
-) -> DataFrame:
+def get_document_frequencies(urns: List[str] = None, cutoff: int = 0, words: List[str] = None) -> DataFrame:
     """Fetch frequency counts of ``words`` in documents (``urns``).
 
     Call the API :py:obj:`~dhlab.constants.BASE_URL` endpoint
@@ -563,7 +565,7 @@ def get_document_frequencies(
     :param list urns: list of uniform resource name strings, for example:
         ``["URN:NBN:no-nb_digibok_2008051404065", "URN:NBN:no-nb_digibok_2010092120011"]``
     :param int cutoff: minimum frequency of a word to be counted
-    :param list words: a list of words to be counted - if left None, whole document is returned.
+    :param list words: a list of words to be counted - if left None, whole document is returned. If not None both the counts and their relative frequency is returned.
     """
     params = locals()
     r = requests.post(f"{BASE_URL}/frequencies", json=params)
@@ -580,8 +582,9 @@ def get_document_frequencies(
         df = df.sort_values(by=df.columns[0], ascending=False).fillna(0)
     else:
         df = pd.DataFrame(result)
-        df.columns = ["urn", "word", "count", "urncount"]
-        df = pd.pivot_table(df, values="count", index="word", columns="urn").fillna(0)
+        df.columns = ["urn", "word", "freq", "urncount"]
+        df['relfreq'] = df['freq']/df.urncount
+        df = pd.pivot_table(df, values=["freq",'relfreq'], index="word", columns="urn").fillna(0)
     return df
 
 
@@ -778,6 +781,38 @@ def konkordans(
     return concordance(**locals())
 
 
+def word_concordance(
+        urn: list = None, dhlabid: list = None, words: list = None, before: int = 12, after: int = 12, limit: int = 100, samplesize: int = 50000
+) -> DataFrame:
+    """Get a list of concordances from the National Library's database.
+
+    Call the API :py:obj:`~dhlab.constants.BASE_URL` endpoint
+    `/conc <https://api.nb.no/dhlab/#/default/conc_word_urn>`_.
+
+    :param list urns: dhlab serial ids. (server can take both urns and dhlabid but so we may rewrite this to)
+    :param str words: Word(s) to search for -- must be a list
+    :param int before: between 0-24.
+    :param int after: between 0-24 (before + sum <= 24)
+    :param int limit: max. number of concordances per server process.
+    :param int samplesize: samples from urns.
+    :return: a table of concordances
+    """
+
+    # server checks if either dhlabid or urns are present in the parameters, so only one of them
+    # is passed. The return is dhlabid anyhow.
+
+    if dhlabid is not None:
+        params = {"dhlabid": dhlabid, "words": words, "before": before, "after": after, "limit": limit, "samplesize":samplesize}
+    elif urns is not None:
+        params = {"urn": urns, "words": words,  "before": before, "after": after, "limit": limit, "samplesize":samplesize}
+    else:
+        params = {"words": words,  "before": before, "after": after, "limit": limit, "samplesize":samplesize}
+
+    r = requests.post(BASE_URL + "/conc_word_urn", json=params)
+
+    return pd.DataFrame([x for y in r.json() for x in y], columns=['dhlabid', 'before','target','after'])
+
+
 def collocation(
         corpusquery: str = "norge", word: str = "arbeid", before: int = 5, after: int = 0
 ) -> DataFrame:
