@@ -6,7 +6,16 @@ import requests
 from dhlab.constants import NGRAM_API, GALAXY_API
 
 
-def get_ngram(terms, corpus='avis', lang='nob'):
+def get_ngram(terms: str, corpus: str = "avis", lang: str = "nob") -> dict:
+    """Fetch raw and relative frequencies for the ``terms``.
+
+    Call the :py:data:`NGRAM_API`.
+    The frequencies are aggregated per year between 1800-2021.
+
+    :param str terms: comma separated string of words
+    :param str corpus: type of documents to search through
+    :return: table of annual frequency counts per term
+    """
     req = requests.get(
         NGRAM_API,
         params={
@@ -22,11 +31,19 @@ def get_ngram(terms, corpus='avis', lang='nob'):
     return json.loads(res)
 
 
-def make_word_graph(words, corpus='all', cutoff=16, leaves=0):
+def make_word_graph(
+        words: str, corpus: str = 'all', cutoff: int = 16, leaves: int = 0
+) -> nx.DiGraph:
     """Get galaxy from ngram-database.
-    corpus is bok, avis or both
-    words is a commaseparated string
-    Set leaves=1 to get the leaves. Parameter cutoff only works for lang='nob'."""
+
+    Call the :py:obj:`~dhlab.constants.GALAXY_API` endpoint.
+
+    :param str words: comma-separated string of words
+    :param str corpus: document type: ``'book'``, ``'avis'``, or ``'all'``,
+    :param int cutoff: Number of nodes to include.
+    :param int leaves: Set leaves=1 to get the leaves.
+    :return: A `networkx.DiGraph` with the results.
+    """
 
     params = dict()
     params['terms'] = words
