@@ -8,8 +8,24 @@ from dhlab.api.dhlab_api import (
     word_lemma, 
     word_lemma_many
 )
+from typing import Union
 
-class WordParadigm():
+class WordbankSuper():
+    """Super class for wordbank classes"""
+    def __init__(self, frame):
+        self.frame = frame
+    
+    def __repr__(self) -> str:
+        return self.frame.__repr__()
+    
+    def _repr_html_(self) -> Union[str, None]:
+        """
+        Return the HTML representation of the DhlabObj frame attribute
+        """
+        return self.frame._repr_html_()
+
+
+class WordParadigm(WordbankSuper):
     """Fetch inflection paradigms for a list of words, or just one word"""
     def __init__(self, words, lang='nob'):
         if isinstance(words, list):
@@ -18,8 +34,10 @@ class WordParadigm():
             self.paradigms = pd.DataFrame(word_paradigm(words, lang))
         else:
             self.paradigms = None
+        
+        super().__init__(self.paradigms)
             
-class WordForm():
+class WordForm(WordbankSuper):
     """Fetch possible forms of a word or list of words"""
     def __init__(self, words, lang='nob'):
         if isinstance(words, list):
@@ -29,7 +47,9 @@ class WordForm():
         else:
             self.forms = None
 
-class WordLemma():
+        super().__init__(self.forms)
+        
+class WordLemma(WordbankSuper):
     """Fetch possbile lemmas for a given word form"""
     def __init__(self, words, lang='nob'):
         if isinstance(words, list):
@@ -39,5 +59,6 @@ class WordLemma():
         else:
             self.lemmas = None
             
+        super().__init__(self.lemmas)
     
     
\ No newline at end of file
